#[repr(transparent)]pub struct CoreId(pub usize);Expand description
This represents a CPU core.
Tuple Fields
0: usizeThe numerical id of a core
Implementations
Sourceimpl CoreId
impl CoreId
Sourcepub fn set_affinity(&self) -> Result<(), Error>
pub fn set_affinity(&self) -> Result<(), Error>
Set the affinity of the current process to this CoreId
Note: This will not fail if the target platform does not support core affinity.
(only on error cases for supported platforms)
If you really need to fail for unsupported platforms (like aarch64 on macOS), use CoreId::set_affinity_forced instead.