pub struct Subscribable<T: Copy> { /* private fields */ }Expand description
Clone-able handle for spawning Subscribers.
Send this to other threads and call subscribe
to create independent consumers.
Implementations
Sourceimpl<T: Copy> Subscribable<T>
impl<T: Copy> Subscribable<T>
Sourcepub fn subscribe(&self) -> Subscriber<T>
pub fn subscribe(&self) -> Subscriber<T>
Create a subscriber that will see only future messages.
Sourcepub fn subscribe_from_oldest(&self) -> Subscriber<T>
pub fn subscribe_from_oldest(&self) -> Subscriber<T>
Create a subscriber starting from the oldest available message still in the ring (or 0 if nothing published yet).